==> rapid_widgets_library-0.0.2.tar.gz: lib/custom-camera.dart <==
/*
Imports Required:
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/view/widgets/custom-camera.dart';

Widget can be parameterised as follows:
An empty container (Height and Width can be parameterised) is shown up as default with suitable messages.
Once the user clicks on "Take a Picture" the native camera app opens up and the image can be clicked.
The image is saved to the gallery as well as shown in the empty container.
The user can specify a callback function to execute once the picture has been taken.

Object:
  callback(){}

SAMPLE IMPLEMENTATION:

child: ImageInput(onSelectImage:callback, height:150, width:100, buttonColour: Colors.red, borderColour: Colors.black)

Here callback is a function defined by the user that takes a image as parameter.

AUTHOR: Soumyadeep Mitra
*/

import 'dart:io';
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/consts.dart';
import 'package:image_picker/image_picker.dart';
import 'package:path/path.dart' as path;
import 'package:path_provider/path_provider.dart' as syspaths;


class ImageInput extends StatefulWidget
{
  final Function onSelectImage;
  final double height;
  final double width;
  final Color buttonColour;
  final Color borderColour;
  final double fontSize;
  ImageInput({this.onSelectImage, this.height, this.width, this.buttonColour, this.borderColour,this.fontSize});
  @override
  _ImageInputState createState() => _ImageInputState();
}


class _ImageInputState extends State<ImageInput>
{
  File _storedImage;
  Future<void> _takePicture() async {
    final imageFile = await ImagePicker.pickImage(
      source: ImageSource.camera,
      maxWidth: maxwidth,
    );
    if (imageFile == null) {
      return;
    }
    setState(() {
      _storedImage = imageFile;
    });
    final appDir = await syspaths.getApplicationDocumentsDirectory();
    final fileName = path.basename(imageFile.path);
    final savedImage = await imageFile.copy('${appDir.path}/$fileName');
    widget.onSelectImage(savedImage);
  }
  @override
  Widget build(BuildContext context) {
    return Row(
      children: <Widget>[
        Container(
          width: widget.width==null?containerwidth:widget.width,
          height: widget.height==null?containerheight:widget.height,
          decoration: BoxDecoration(
            border: Border.all(width: 1, color: widget.borderColour==null?Theme.of(context).primaryColorDark:widget.borderColour),
          ),
          child: _storedImage != null
              ? Image.file(
            _storedImage,
            fit: BoxFit.cover,
            width: double.infinity,
          )
              : Text(
            'No Image Taken',
            textAlign: TextAlign.center,
          ),
          alignment: Alignment.center,
        ),
        SizedBox(
          width: 10,
        ),
        Expanded(
          child: FlatButton.icon(
            icon: Icon(Icons.camera),
            label: Text('Take Picture',style: TextStyle(
                fontSize: (widget.fontSize != null) ? widget.fontSize : 14
            )),

            textColor: widget.buttonColour==null?Theme.of(context).primaryColorDark:widget.buttonColour,
            onPressed: _takePicture,
          ),
        ),
      ],
    );
  }
}

==> rapid_widgets_library-0.2.3.tar.gz: lib/custom-camera.dart <==
/*
Imports Required:
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/view/widgets/custom-camera.dart';

Widget can be parameterised as follows:
An empty container (Height and Width can be parameterised) is shown up as default with suitable messages.
Once the user clicks on "Take a Picture" the native camera app opens up and the image can be clicked.
The image is saved to the gallery as well as shown in the empty container.
The user can specify a callback function to execute once the picture has been taken.

Object:
  callback(){}

SAMPLE IMPLEMENTATION:

child: ImageInput(onSelectImage:callback, height:150, width:100, buttonColour: Colors.red, borderColour: Colors.black)

Here callback is a function defined by the user that takes a image as parameter.

AUTHOR: Soumyadeep Mitra
*/

import 'dart:io';
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/consts.dart';
import 'package:image_picker/image_picker.dart';
import 'package:path/path.dart' as path;
import 'package:path_provider/path_provider.dart' as syspaths;

class ImageInput extends StatefulWidget {
  final Function onSelectImage;
  final double height;
  final double width;
  final Color buttonColour;
  final Color borderColour;
  final double fontSize;
  ImageInput(
      {this.onSelectImage,
      this.height,
      this.width,
      this.buttonColour,
      this.borderColour,
      this.fontSize});
  @override
  _ImageInputState createState() => _ImageInputState();
}

class _ImageInputState extends State<ImageInput> {
  File _storedImage;

  get imagePicker => null;
  Future<void> _takePicture() async {
    final imageFile = await imagePicker.getImage(
      source: ImageSource.camera,
      maxWidth: maxwidth,
    );
    if (imageFile == null) {
      return;
    }
    setState(() {
      _storedImage = imageFile;
    });
    final appDir = await syspaths.getApplicationDocumentsDirectory();
    final fileName = path.basename(imageFile.path);
    final savedImage = await imageFile.copy('${appDir.path}/$fileName');
    widget.onSelectImage(savedImage);
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: <Widget>[
        Container(
          width: widget.width == null ? containerwidth : widget.width,
          height: widget.height == null ? containerheight : widget.height,
          decoration: BoxDecoration(
            border: Border.all(
                width: 1,
                color: widget.borderColour == null
                    ? Theme.of(context).primaryColorDark
                    : widget.borderColour),
          ),
          child: _storedImage != null
              ? Image.file(
                  _storedImage,
                  fit: BoxFit.cover,
                  width: double.infinity,
                )
              : Text(
                  'No Image Taken',
                  textAlign: TextAlign.center,
                ),
          alignment: Alignment.center,
        ),
        SizedBox(
          width: 10,
        ),
        Expanded(
          child: FlatButton.icon(
            icon: Icon(Icons.camera),
            label: Text('Take Picture',
                style: TextStyle(
                    fontSize:
                        (widget.fontSize != null) ? widget.fontSize : 14)),
            textColor: widget.buttonColour == null
                ? Theme.of(context).primaryColorDark
                : widget.buttonColour,
            onPressed: _takePicture,
          ),
        ),
      ],
    );
  }
}
